@@ -13,6 +13,7 @@ import sys
 import utils
 from mundo import Mundo
 import actores
+import grupo
 import escena
 import escenas
 import fondos
@@ -82,7 +83,7 @@ def iniciar(ancho=640, alto=480, titulo='Pilas', usar_motor='qtgl',
                 mundo.motor.ventana.show()
     else:
         mundo.motor.modificar_ventana(ancho, alto, titulo, pantalla_completa)
-        mundo.fisica.definir_gravedad(*gravedad)
+        escena_actual().fisica.definir_gravedad(*gravedad)
 
 
 def esta_inicializada():
