@@ -19,21 +19,31 @@ class Temporizador(Texto):
         >>> t = pilas.actores.Temporizador()
         >>> def hola_mundo():
         ...     pilas.avisar("Hola mundo, pasaron 10 segundos...")
-        ... 
+        ...
         >>> t.ajustar(10, hola_mundo)
         >>> t.iniciar()
 
     """
     def __init__(self, x=0, y=0, color=colores.negro):
+        """Inicializa el temporizador.
+
+        :param x: Posición horizontal.
+        :param y: Posición vertical.
+        :param color: El color que tendrá el texto.
+        """
         Texto.__init__(self, '0', x=x, y=y)
         self.ajustar(1, self.funcion_vacia)
         self.color = color
 
-    # funcion cuando no se ajusta temporizador   
+    # funcion cuando no se ajusta temporizador
     def funcion_vacia(self):
         pass
 
     def definir_tiempo_texto(self, variable):
+        """Define el texto a mostrar en el temporizador.
+
+        :param variable: La cadena de texto a mostrar.
+        """
         self.texto = str(variable)
 
     # con la funcion ajustar manipulamos el tiempo y la
@@ -42,10 +52,10 @@ class Temporizador(Texto):
         """Indica una funcion para ser invocada en el tiempo indicado.
 
         La función no tiene que recibir parámetros, y luego de
-        ser indicada se tiene que iniciar el temporizador. 
+        ser indicada se tiene que iniciar el temporizador.
         """
 
-        self.tiempo = tiempo 
+        self.tiempo = tiempo
         self.definir_tiempo_texto(self.tiempo)
 
         if funcion == None:
@@ -58,9 +68,8 @@ class Temporizador(Texto):
             self.tiempo -= 1
             self.definir_tiempo_texto(self.tiempo)
             return True
-    
+
     def iniciar(self):
         """Inicia el contador de tiempo con la función indicada."""
         pilas.mundo.agregar_tarea_una_vez(self.tiempo, self.funcion)
         pilas.mundo.agregar_tarea_siempre(1, self._restar_a_contador)
-        
