@@ -1,10 +1,12 @@
 import pilas
 
-class EscenaMenu(pilas.escenas.Escena):
+class EscenaMenu(pilas.escena.Base):
     "Escena de presentacion del juego."
 
     def __init__(self):
-        pilas.actores.utils.eliminar_a_todos()
+        pilas.escena.Base.__init__(self)
+        
+    def iniciar(self):
         pilas.fondos.Fondo('data/inicio.png')
         self.menu_de_juego()
 
@@ -17,14 +19,12 @@ class EscenaMenu(pilas.escenas.Escena):
         self.menu = pilas.actores.Menu(opciones_menu, y = -50)
 
     def iniciar_juego(self):
-        self.menu.desactivar()
         import escena_juego
-        escena_juego.Juego()
+        pilas.cambiar_escena(escena_juego.Juego())
 
     def salir_del_juego(self):
         pilas.terminar()
 
     def mostrar_ayuda(self):
-        self.menu.desactivar()
         import escena_ayuda
-        escena_ayuda.Ayuda()
+        pilas.cambiar_escena(escena_ayuda.Ayuda())
