@@ -19,8 +19,10 @@ PATH = os.path.dirname(os.path.abspath(__file__))
 
 
 def es_interpolacion(an_object):
-    "Indica si un objeto se comporta como una colisión."
+    """Indica si un objeto se comportará como una interpolación.
 
+    :param an_object: El objeto a consultar.
+    """
     return isinstance(an_object, interpolaciones.Interpolacion)
 
 
@@ -30,6 +32,8 @@ def obtener_ruta_al_recurso(ruta):
     Los archivos de recursos (como las imagenes) se buscan en varios
     directorios (ver docstring de image.load), así que esta
     función intentará dar con el archivo en cuestión.
+
+    :param ruta: Ruta al archivo (recurso) a inspeccionar.
     """
 
     dirs = ['./', os.path.dirname(sys.argv[0]), 'data', PATH, PATH + '/data']
@@ -47,7 +51,7 @@ def obtener_ruta_al_recurso(ruta):
 
 
 def esta_en_sesion_interactiva():
-    "Indica si pilas se ha ejecutado desde una consola interactiva de python."
+    """Indica si pilas se ha ejecutado desde una consola interactiva de python."""
     import sys
     try:
         cursor = sys.ps1
@@ -63,17 +67,39 @@ def esta_en_sesion_interactiva():
     return False
 
 def distancia(a, b):
-    "Retorna la distancia entre dos numeros."
+    """Retorna la distancia entre dos numeros.
+
+        >>> distancia(30, 20)
+        10
+
+    :param a: Un valor numérico.
+    :param b: Un valor numérico.
+    """
     return abs(b - a)
 
 def distancia_entre_dos_puntos((x1, y1), (x2, y2)):
-    "Retorna la distancia entre dos puntos en dos dimensiones."
+    """Retorna la distancia entre dos puntos en dos dimensiones.
+
+    :param x1: Coordenada horizontal del primer punto.
+    :param y1: Coordenada vertical del primer punto.
+    :param x2: Coordenada horizontal del segundo punto.
+    :param y2: Coordenada vertical del segundo punto.
+    """
     return math.sqrt(distancia(x1, x2) ** 2 + distancia(y1, y2) ** 2)
 
 def distancia_entre_dos_actores(a, b):
+    """Retorna la distancia en pixels entre dos actores.
+
+    :param a: El primer actor.
+    :param b: El segundo actor.
+    """
     return distancia_entre_dos_puntos((a.x, a.y), (b.x, b.y))
 
 def actor_mas_cercano_al_actor(actor):
+    """Retorna el actor de la escena que esté mas cercano a otro indicado por parámetro.
+
+    :param actor: El actor tomado como referencia.
+    """
     actor_mas_cercano = None
     distancia = 999999
     for actor_cercano in pilas.escena_actual().actores:
@@ -84,11 +110,24 @@ def actor_mas_cercano_al_actor(actor):
     return actor_mas_cercano
 
 def colisionan(a, b):
-    "Retorna True si dos actores estan en contacto."
+    """Retorna True si dos actores estan en contacto.
+
+    :param a: Un actor.
+    :param b: El segundo actor a verificar.
+    """
     return distancia_entre_dos_actores(a, b) < a.radio_de_colision + b.radio_de_colision
 
 def interpolable(f):
-    "Decorador que se aplica a un metodo para que permita animaciones de interpolaciones."
+    """Decorador que se aplica a un metodo para que permita animaciones de interpolaciones.
+
+    Ejemplo::
+
+        @interpolable
+        def set_x(self, valor_x):
+            [...]
+
+    :param f: Método sobre el que va a trabajar el interpolador.
+    """
 
     def inner(*args, **kwargs):
         value = args[1]
@@ -115,14 +154,21 @@ def interpolable(f):
     return inner
 
 def hacer_coordenada_mundo(x, y):
+    """Convierte una coordenada de pantalla a una coordenada dentro del motor de física.
+
+    :param x: Coordenada horizontal.
+    :param y: Coordenada vertical.
+    """
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x + dx, dy - y)
 
 def hacer_coordenada_pantalla_absoluta(x, y):
+    # TODO: Duplicado del codigo anterior?
     dx, dy = pilas.mundo.motor.centro_fisico()
     return (x + dx, dy - y)
 
 def listar_actores_en_consola():
+    """Imprime una lista de todos los actores en la escena sobre la consola."""
     todos = pilas.escena_actual().actores
 
     print "Hay %d actores en la escena:" %(len(todos))
@@ -134,6 +180,11 @@ def listar_actores_en_consola():
     print ""
 
 def obtener_angulo_entre(punto_a, punto_b):
+    """Retorna el ángulo entro dos puntos de la pantalla.
+
+    :param punto_a: Una tupla con la coordenada del primer punto.
+    :param punto_b: Una tupla con la coordenada del segundo punto.
+    """
     (x, y) = punto_a
     (x1, y1) = punto_b
     return math.degrees(math.atan2(y1 - y, x1 -x))
@@ -147,11 +198,14 @@ def convertir_de_posicion_fisica_relativa(x, y):
     return (x - dx, dy - y)
 
 def calcular_tiempo_en_recorrer(distancia_en_pixeles, velocidad):
-    """ Calcula el tiempo que se tardará en recorrer una distancia en 
-    pixeles con una velocidad constante """
+    """Calcula el tiempo que se tardará en recorrer una distancia en
+    pixeles con una velocidad constante.
 
+    :param distancia_en_pixeles: La longitud a recorrer medida en pixels.
+    :param velocidad: La velocida medida en pixels.
+    """
     if (pilas.mundo.motor.canvas.fps.cuadros_por_segundo_numerico > 0):
-        return (distancia_en_pixeles / (pilas.mundo.motor.canvas.fps.cuadros_por_segundo_numerico * velocidad))        
+        return (distancia_en_pixeles / (pilas.mundo.motor.canvas.fps.cuadros_por_segundo_numerico * velocidad))
     else:
         return 0
 
@@ -159,19 +213,18 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
     """Retorna un objeto que representa cambios de atributos progresivos.
 
     El resultado de esta función se puede aplicar a varios atributos
-    de los actores, por ejemplo::
+    de los actores, por ejemplo:
 
-        bomba = pilas.actores.Bomba()
-        bomba.escala = pilas.interpolar(3)
+        >>> bomba = pilas.actores.Bomba()
+        >>> bomba.escala = pilas.interpolar(3)
 
     Esta función también admite otros parámetros cómo:
 
-        - duracion: es la cantidad de segundos que demorará toda la interpolación.
-        - demora: cuantos segundos se deben esperar antes de iniciar.
-        - tipo: es el algoritmo de la interpolación, puede ser 'lineal'.
+    :param duracion: es la cantidad de segundos que demorará toda la interpolación.
+    :param demora: cuantos segundos se deben esperar antes de iniciar.
+    :param tipo: es el algoritmo de la interpolación, puede ser 'lineal'.
     """
 
-
     import interpolaciones
 
     algoritmos = {
@@ -197,12 +250,12 @@ def interpolar(valor_o_valores, duracion=1, demora=0, tipo='lineal'):
 
 
 def deneter_interpolacion(objeto, propiedad):
-    """ Deteiene una interpolación iniciada en un campo de un objeto.
-
-        param: objeto: Actor del que se desea detener al interpolacion.
-        para: propiedad: Cadena de texto que indica la propiedad del objeto cuya interpolación se desea terminar.
+    """Deteiene una interpolación iniciada en un campo de un objeto.
 
        >>> pilas.utils.deneter_interpolacion(actor, 'y')
+
+    :param objeto: Actor del que se desea detener al interpolacion.
+    :para propiedad: Cadena de texto que indica la propiedad del objeto cuya interpolación se desea terminar.
     """
     setter = 'set_' + propiedad
     try:
@@ -212,18 +265,23 @@ def deneter_interpolacion(objeto, propiedad):
         print "El obejto %s no tiene esa propiedad %s" %(objeto.__class__.__name__, setter)
 
 def obtener_area():
-    "Retorna el area que ocupa la ventana"
+    """Retorna el area que ocupa la ventana"""
     return pilas.mundo.motor.obtener_area()
 
 def obtener_bordes():
+    """Retorna los bordes de la pantalla en forma de tupla."""
     ancho, alto = pilas.mundo.motor.obtener_area()
     return -ancho/2, ancho/2, alto/2, -alto/2
 
 def obtener_area_de_texto(texto):
-    "Informa el ancho y alto que necesitara un texto para imprimirse."
+    """Informa el ancho y alto que necesitara un texto para imprimirse.
+
+    :param texto: La cadena de texto que se quiere imprimir.
+    """
     return pilas.mundo.motor.obtener_area_de_texto(texto)
 
 def realizar_pruebas():
+    """Imprime pruebas en pantalla para detectar si pilas tiene todas las dependencias instaladas."""
     print "Realizando pruebas de dependencias:"
     print ""
 
@@ -260,7 +318,12 @@ def realizar_pruebas():
         print "Cuidado -> no se encuentra PIL."
 
 def ver_codigo(objeto, imprimir, retornar):
-    """Imprime en pantalla el codigo fuente asociado a un objeto."""
+    """Imprime en pantalla el codigo fuente asociado a un objeto.
+
+    :param objeto: El objeto que se quiere inspeccionar.
+    :param imprimir: Un valor True o False indicando si se quiere imprimir directamente sobre la pantalla.
+    :param retornar: Un valor True o False indicando si se quiere obtener el código como un string.
+    """
     import inspect
 
     try:
@@ -275,9 +338,14 @@ def ver_codigo(objeto, imprimir, retornar):
         return codigo
 
 def obtener_uuid():
+    """Genera un identificador único."""
     return str(uuid.uuid4())
 
 def abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo):
+    """Intenta abrir un archivo con la herramienta recomenda por el sistema operativo.
+
+    :param ruta_al_archivo: La ruta al archivo que se quiere abrir.
+    """
     if sys.platform.startswith('darwin'):
         subprocess.call(('open', ruta_al_archivo))
     elif os.name == 'nt':
@@ -286,17 +354,27 @@ def abrir_archivo_con_aplicacion_predeterminada(ruta_al_archivo):
         subprocess.call(('xdg-open', ruta_al_archivo))
 
 def centrar_ventana(widget):
+    """Coloca la ventana o widget directamente en el centro del escritorio.
+
+    :param widget: Widget que representa la ventana.
+    """
     from PyQt4 import QtGui
     desktop = QtGui.QApplication.desktop()
     widget.move(desktop.screen().rect().center() - widget.rect().center())
 
 def descargar_archivo_desde_internet(parent, url, archivo_destino):
+    """Inicia la descarga de una archivo desde Internet.
+
+    :param parent: El widget que será padre de la ventana.
+    :param url: La URL desde donde se descargará el archivo.
+    :param archivo_destino: La ruta en donde se guardará el archivo.
+    """
     import descargar
     ventana = descargar.Descargar(parent, url, archivo_destino)
     ventana.show()
 
 def imprimir_todos_los_eventos():
-    "Muestra en consola los eventos activos y a quienes invocan"
+    """Muestra en consola los eventos activos y a quienes invocan"""
     import pilas
 
     for x in dir(pilas.escena_actual()):
@@ -314,3 +392,28 @@ def habilitar_depuracion():
     pyqtRemoveInputHook()
     set_trace()
 
+def mostrar_mensaje_de_error_y_salir(motivo):
+    """Muestra un mensaje de error y termina con la ejecución de pilas.
+
+    :param motivo: Un mensaje que explica el problema o la razón del cierre de pilas.
+    """
+    from PyQt4 import QtGui
+    app = QtGui.QApplication(sys.argv[:1])
+    app.setApplicationName("pilas-engine error")
+    main_window = QtGui.QMainWindow()
+    main_window.show()
+    main_window.raise_()
+    QtGui.QMessageBox.critical(main_window, "Error", motivo)
+    app.exit()
+    sys.exit(1)
+
+def obtener_archivo_a_ejecutar_desde_argv():
+    """Obtiene la ruta del archivo a ejecutar desde la linea de argumentos del programa."""
+    import sys, copy
+
+    argv = copy.copy(sys.argv)
+
+    if '-i' in argv:
+        argv.remove('-i')
+
+    return " ".join(sys.argv[1:])
